@@ -25,6 +25,7 @@
     'deletePort',
     'deletePortgroup',
     'getDrivers',
+    'getDriverDetails',
     'getDriverProperties',
     'getNode',
     'getNodes',
@@ -33,10 +34,12 @@
     'getPortsWithNode',
     'getBootDevice',
     'getSupportedBootDevices',
+    'injectNmi',
     'nodeGetConsole',
     'nodeSetBootDevice',
     'nodeSetConsoleMode',
     'nodeSetPowerState',
+    'nodeSetRaidConfig',
     'nodeSetMaintenance',
     'setNodeProvisionState',
     'updateNode',
@@ -119,10 +122,31 @@
         it('getDrivers', function() {
           ironicAPI.getDrivers()
             .then(function(drivers) {
-              expect(drivers.length).toBeGreaterThan(0);
-              angular.forEach(drivers, function(driver) {
-                expect(driver.name).toBeDefined();
-              });
+              expect(drivers).toEqual(ironicBackendMockService.getBaseDrivers());
+            })
+          .catch(failTest);
+
+          ironicBackendMockService.flush();
+        });
+
+        it('getDriverDetails', function() {
+          var driver = ironicBackendMockService.params.defaultDriver;
+          ironicAPI.getDriverDetails(driver)
+            .then(function(details) {
+              var drivers = ironicBackendMockService.getDrivers();
+              expect(details).toEqual(drivers[driver].details);
+            })
+          .catch(failTest);
+
+          ironicBackendMockService.flush();
+        });
+
+        it('getDriverProperties', function() {
+          var driver = ironicBackendMockService.params.defaultDriver;
+          ironicAPI.getDriverProperties(driver)
+            .then(function(properties) {
+              var drivers = ironicBackendMockService.getDrivers();
+              expect(properties).toEqual(drivers[driver].properties);
             })
           .catch(failTest);
 
@@ -388,6 +412,48 @@
           ironicBackendMockService.flush();
         });
 
+        it('nodeSetRaidConfig', function() {
+          var raid = {
+            logical_disks: [{size_gb: 10, raid_level: '1', is_root_volume: false}]
+          };
+          createNode({driver: defaultDriver})
+            .then(function(node) {
+              return ironicAPI.nodeSetRaidConfig(node.uuid, raid)
+                .then(function() {
+                  return node;
+                });
+            })
+            .then(function(node) {
+              ironicAPI.getNode(node.uuid).then(function(node) {
+                expect(node.target_raid_config).toEqual(raid);
+              });
+            })
+            .catch(failTest);
+
+          ironicBackendMockService.flush();
+        });
+
+        it('nodeSetRaidConfig - bad config', function() {
+          var badConfig = {
+            logical_disks: [{size_gb: 10, is_root_volume: false}]
+          };
+
+          createNode({driver: defaultDriver})
+            .then(function(node) {
+              ironicAPI.nodeSetRaidConfig(node.uuid, badConfig)
+                .then(function() {
+                  // Ensure the target raid config is unchanged
+                  ironicAPI.getNode(node.uuid)
+                    .then(function() {
+                      expect(node.target_raid_config).toEqual({});
+                    });
+                });
+            })
+            .catch(failTest);
+
+          ironicBackendMockService.flush();
+        });
+
         it('createPort', function() {
           var macAddr = '00:00:00:00:00:00';
           var node;
@@ -596,6 +662,27 @@
 
           ironicBackendMockService.flush();
         });
+
+        it('injectNmi', function() {
+          createNode({driver: defaultDriver})
+            .then(function(node) {
+              return ironicAPI.injectNmi(node.uuid);
+            })
+            .then(function(response) {
+              expect(response.status).toBe(204);
+              expect(response.data).toBe('');
+            })
+            .catch(failTest);
+
+          ironicBackendMockService.flush();
+        });
+
+        it('injectNmi - nonexistent node', function() {
+          ironicAPI.injectNmi(0)
+            .then(failTest);
+
+          ironicBackendMockService.flush();
+        });
       });
     });
 })();
